<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Seo Cross Linking Hyva Compatibility
 */

namespace Amasty\CrossLinksHyva\Plugin\CrossLinks\Model\ReplaceManager;

use Amasty\CrossLinks\Model\ReplaceManager;
use Amasty\CrossLinksHyva\Model\SkipFlag;
use Hyva\Theme\Service\CurrentTheme;
use Magento\Catalog\Helper\Output;

class CheckSkipFlag
{
    /**
     * @var SkipFlag
     */
    private $skipFlag;

    /**
     * @var CurrentTheme
     */
    private $currentTheme;

    public function __construct(
        SkipFlag $skipFlag,
        CurrentTheme $currentTheme
    ) {
        $this->skipFlag = $skipFlag;
        $this->currentTheme = $currentTheme;
    }

    /**
     * @param ReplaceManager $subject
     * @param callable $proceed
     * @param Output $output
     * @param string $content
     * @param array $params
     * @return string
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function aroundProductAttribute(
        ReplaceManager $subject,
        callable $proceed,
        Output $output,
        ?string $content,
        array $params
    ): ?string {
        if ($this->shouldSkip()) {
            return $content;
        }

        return $proceed($output, $content, $params);
    }

    private function shouldSkip(): bool
    {
        return $this->currentTheme->isHyva() && $this->skipFlag->isSkip();
    }
}
