<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Seo Cross Linking Hyva Compatibility
 */

namespace Amasty\CrossLinksHyva\Plugin\Hyva\Theme\ViewModel\ProductPage;

use Amasty\CrossLinks\Model\ReplaceManager;
use Amasty\CrossLinksHyva\Model\SkipFlag;
use Hyva\Theme\ViewModel\ProductPage;
use Magento\Catalog\Helper\Output;
use Magento\Catalog\Model\Product;

class ProcessShortDescription
{
    /**
     * @var ReplaceManager
     */
    private $replaceManager;

    /**
     * @var Output
     */
    private $outputHelper;

    /**
     * @var SkipFlag
     */
    private $skipFlag;

    public function __construct(
        ReplaceManager $replaceManager,
        Output $outputHelper,
        SkipFlag $skipFlag
    ) {
        $this->replaceManager = $replaceManager;
        $this->outputHelper = $outputHelper;
        $this->skipFlag = $skipFlag;
    }

    /**
     * @param ProductPage $subject
     * @param Product $product
     * @param bool $excerpt
     * @param bool $stripTags
     * @return array
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function beforeGetShortDescriptionForProduct(
        ProductPage $subject,
        Product $product,
        bool $excerpt = true,
        bool $stripTags = true
    ): array {
        $this->skipFlag->setSkip(true);

        return [$product, $excerpt, $stripTags];
    }

    /**
     * @param ProductPage $subject
     * @param string $result
     * @return string
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function afterGetShortDescriptionForProduct(ProductPage $subject, string $result): string
    {
        $this->skipFlag->setSkip(false);

        return $this->replaceManager->productAttribute(
            $this->outputHelper,
            $result,
            ['attribute' => 'short_description']
        );
    }
}
